External Examples
=================

Here are a list of longer, more technical examples of what PyVista can do!

.. caution::

    Please note that these examples link to external websites.
    If any of these links are broken, please raise an issue on the repository.


Do you have a technical processing workflow or visualization routine you
would like to share?
If so, please consider sharing your work here by clicking the `Edit on GitHub`
button at the top of this page and adding a link to your project!


.. toctree::
   :maxdepth: 2

   3D visualization for the Open Mining Format (omf) <https://github.com/OpenGeoVis/omfvista/blob/master/Example.ipynb>
   Live example notebook showcasing omfvista <https://mybinder.org/v2/gh/OpenGeoVis/omfvista-demo/master?filepath=notebooks%2FExample.ipynb>
   3D Rendering with Discretize <http://discretize.simpeg.xyz/en/master/auto_examples/pyvista_demo.html#sphx-glr-auto-examples-pyvista-demo-py>
   OpenFOAM Rendering <https://pswpswpsw.github.io/posts/2018/09/blog-post-modify-vtk-openfoam/>
   FORGE Geothermal Project <http://forge.pvgeo.org>
   PVGeo's example gallery <https://pvgeo.org/examples/index.html>
